@@ -143,7 +143,7 @@ class GeneratePPT(Logger):
             app_id = app_list[idx]
             hl_id = hl_list[idx]
             app_title = self._config.title_list[idx]
-            self.info(f'Working on pages for {app_title}')
+            self.info(f'********************* Working on pages for {app_title} ******************************')
             self._ppt.replace_text(f'{{app{app_no}_name}}',app_title)
 
             if self._config.aip_active:
@@ -291,11 +291,11 @@ class GeneratePPT(Logger):
             #replaceHighlight application specific data
             if self._config.hl_active and self._hl_data.has_data(hl_id):
                 (oss_crit,oss_high,oss_med,lic,components) = self.oss_risk_assessment(hl_id,app_no,day_rate)
-                # fix_now_total.add_effort(oss_crit.effort)
-                # fix_now_total.add_violations(oss_crit.violations)
+                fix_now_total.add_effort(oss_crit.effort)
+                fix_now_total.add_violations(oss_crit.violations)
 
-                # near_term_total.add_effort(oss_high.effort)
-                # near_term_total.add_effort(oss_med.effort)
+                near_term_total.add_effort(oss_high.effort)
+                near_term_total.add_effort(oss_med.effort)
 
                 hl_near_term_total.add_effort(oss_high.effort)
                 hl_near_term_total.add_effort(oss_med.effort)
